*Interact between military distance and legislative ratification requirements
*code from Brambor et al. 2006
drop if bilat==0
drop if demdum==0
gen interactmr=ratification*militdist

version 8.0 
#delimit ;

probit oblig ratification militdist interactmr votediff threatstate threatavgmem, robust cluster (ccode);

preserve;
drawnorm MG_b1-MG_b7, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi bla
            using sim , replace;
            noisily display "start";
          

local a= 0 ;
while `a' <=   5.9 { ;

    {;

scalar h_ratification= 0;
scalar h_votediff= 14.01938;
scalar h_threatstate=.196615;
scalar h_threatavgmem=.1926605;
scalar h_constant=1;

    generate x_betahat0 = MG_b1*h_ratification
                            + MG_b2*(`a')
                            + MG_b3*h_ratification*(`a')
                            + MG_b4*h_votediff
                            + MG_b5*h_threatstate
			    + MG_b6*h_threatavgmem
                            + MG_b7*h_constant;
    
    
    generate x_betahat1 = MG_b1*(h_ratification + 1)
                            + MG_b2*`a'
                            + MG_b3*(h_ratification + 1)*(`a')
                            + MG_b4*h_votediff
                            + MG_b5*h_threatstate
			    + MG_b6*h_threatavgmem
                            + MG_b7*h_constant; 
    
    gen prob0=norm(x_betahat0);
    gen prob1=norm(x_betahat1);
    gen diff=prob1-prob0;
    
    egen probhat0=mean(prob0);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    
	
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi bla;

		
    _pctile prob0, p(5,95) ;
    scalar `lo0' = r(r1);
    scalar `hi0' = r(r2);  
    
    _pctile prob1, p(5,95);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(5,95);
    scalar `diff_lo'= r(r1);
    scalar `diff_hi'= r(r2);  

   
    scalar `prob_hat0'=probhat0;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
	
	scalar `bla'= `a';
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`diff_lo') (`diff_hi') (`bla');
    };      
    drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat;
    
		
	local a=`a'+ 0.5 ;
    display "." _c;
    } ;

display "";

postclose mypost;

use sim, clear;

gen MV = _n-1;

graph twoway line diff_hat bla, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line diff_lo  bla, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line diff_hi  bla, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(0 1 2 3 4 5 6, labsize(3)) 
            ylabel(-.1 0 0.1, labsize(3))
            yscale(noline)
            xscale(noline)
            yline(0)
            legend(off)
            title("Marginal Effect of Legisl. Appr. Req. As Preference Divergence Changes", size(4))
            subtitle(" " "Dependent Variable: Defense Pact" " ", size(3))
            xtitle("Preference Divergence", size(3.5)  )
            ytitle("Marginal Effect of Legisl. Appr. Req.", size(3.5))
            xsca(titlegap(2))
            ysca(titlegap(2))
            scheme(s2mono) graphregion(fcolor(white));
